@@ -483,7 +483,9 @@ sub evt_process_exit {
       my $hadoop_flag=0;my $count=0;
       foreach my $line (reverse @lines) {
          $count++;
-         if ($line=~/ACCESS (?:HADOOP|KALI|OPENLDAP|CATALYST)/) {
+         if ($line=~/GNU.io/) {
+            next;
+         } elsif ($line=~/ACCESS (?:HADOOP|KALI|OPENLDAP|CATALYST|GNU)/) {
             last;
          } elsif ($line=~/ACCESS.*AT:\s+http:/ && $count<70) {
             $webapp_url=$line;
